@@ -88,11 +88,23 @@ public: // Convenience Functions
     IPerm getPermission() const;
 
 public:
-    void save(FILE *fp);
+    bool isEmpty() const;
+
+    bool isNameMatch(const char *otherName) const;
+    bool isNameMatch(const std::string &otherName) const;
+
+    bool isLabelMatch(const char *otherLabel) const;
+    bool isLabelMatch(const std::string &otherLabel) const;
 
 public:
-    void apply(const char *format = nullptr, ...) ATTRIBUTE_FORMAT_PRINTF(2, 3);
-    void define(const char *format = nullptr, ...) ATTRIBUTE_FORMAT_PRINTF(2, 3);
+    void save(FILE *fp) const;
+
+public:
+    void apply(const char *format, ...) const ATTRIBUTE_FORMAT_PRINTF(2, 3);
+    void define(const char *format, ...) const ATTRIBUTE_FORMAT_PRINTF(2, 3);
+
+    void apply() const  { apply(nullptr);  }
+    void define() const { define(nullptr); }
 
 public:
     INDI::PropertyView<INumber> *getNumber() const;
@@ -106,50 +118,4 @@ protected:
     Property(PropertyPrivate &dd);
 };
 
-inline void Property::save(FILE *fp)
-{
-    switch (getType())
-    {
-        case INDI_NUMBER: IUSaveConfigNumber (fp, getNumber()); break;
-        case INDI_TEXT:   IUSaveConfigText   (fp, getText());   break;
-        case INDI_SWITCH: IUSaveConfigSwitch (fp, getSwitch()); break;
-        //case INDI_LIGHT:  IUSaveConfigLight  (fp, getLight());  break;
-        case INDI_BLOB:   IUSaveConfigBLOB   (fp, getBLOB());   break;
-        default:;;
-    }
-}
-
-// TODO (move to server side)
-inline void Property::apply(const char *format, ...)
-{
-    va_list ap;
-    va_start(ap, format);
-    switch (getType())
-    {
-        case INDI_NUMBER: IDSetNumberVA(getNumber(), format, ap); break;
-        case INDI_TEXT:   IDSetTextVA(getText(),     format, ap); break;
-        case INDI_SWITCH: IDSetSwitchVA(getSwitch(), format, ap); break;
-        case INDI_LIGHT:  IDSetLightVA(getLight(),   format, ap); break;
-        case INDI_BLOB:   IDSetBLOBVA(getBLOB(),     format, ap); break;
-        default:;;
-    }
-    va_end(ap);
-}
-
-inline void Property::define(const char *format, ...)
-{
-    va_list ap;
-    va_start(ap, format);
-    switch (getType())
-    {
-        case INDI_NUMBER: IDDefNumberVA(getNumber(), format, ap); break;
-        case INDI_TEXT:   IDDefTextVA(getText(),     format, ap); break;
-        case INDI_SWITCH: IDDefSwitchVA(getSwitch(), format, ap); break;
-        case INDI_LIGHT:  IDDefLightVA(getLight(),   format, ap); break;
-        case INDI_BLOB:   IDDefBLOBVA(getBLOB(),     format, ap); break;
-        default:;;
-    }
-    va_end(ap);
-}
-
 } // namespace INDI
